@@ -1,5 +1,5 @@
 (* camlp5r *)
-(* $Id: pr_depend.ml,v 6.14 2012-01-09 14:22:21 deraugla Exp $ *)
+(* $Id: pr_depend.ml,v 6.17 2013-07-02 16:12:43 deraugla Exp $ *)
 (* Copyright (c) INRIA 2007-2012 *)
 
 #load "pa_macro.cmo";
@@ -87,6 +87,7 @@ value rec patt =
   | <:patt< [| $list:pl$ |] >> -> list patt pl
   | PaChr _ _ -> ()
   | PaInt _ _ _ -> ()
+  | PaFlo _ _ -> ()
   | <:patt< ~{$_$ $opt:po$} >> -> option patt po
   | <:patt< $lid:_$ >> -> ()
   | <:patt< ?{$_$ = $e$} >> -> expr e
@@ -98,6 +99,7 @@ value rec patt =
   | <:patt< ($list:pl$) >> -> list patt pl
   | <:patt< ($p$ : $t$) >> -> do { patt p; ctyp t }
   | <:patt< $uid:_$ >> -> ()
+  | <:patt< (module $_$ : $mt$) >> -> module_type mt
   | PaVrn _ _ -> ()
   | x -> not_impl "patt" x ]
 and patt_module =
@@ -226,7 +228,7 @@ and str_item =
   | <:str_item< include $me$ >> -> module_expr me
   | <:str_item< module $flag:_$ $list:nel$ >> ->
       list (fun (_, me) -> module_expr me) nel
-  | <:str_item< module type $uid:_$ = $mt$ >> -> module_type mt
+  | <:str_item< module type $_$ = $mt$ >> -> module_type mt
   | <:str_item< open $[s :: _]$ >> -> addmodule s
   | <:str_item< type $list:tdl$ >> -> list type_decl tdl
   | <:str_item< value $flag:_$ $list:pel$ >> -> list let_binding pel
