@@ -1,5 +1,5 @@
 (* camlp5r *)
-(* $Id: ast2pt.ml,v 6.50 2012-06-06 09:36:54 deraugla Exp $ *)
+(* $Id: ast2pt.ml,v 6.53 2013-03-19 15:25:22 deraugla Exp $ *)
 
 #load "q_MLast.cmo";
 
@@ -91,7 +91,8 @@ value mklazy loc e =
       in
       let f = ghexp (ocaml_pexp_function "" None [(void_pat, e)]) in
       let delayed = Ldot (Lident "Lazy") "Delayed" in
-      let df = ghexp (ocaml_pexp_construct delayed (Some f) False) in
+      let cloc = mkloc loc in
+      let df = ghexp (ocaml_pexp_construct cloc delayed (Some f) False) in
       let r = ghexp (ocaml_pexp_ident (Ldot (Lident "Pervasives") "ref")) in
       ghexp (ocaml_pexp_apply r [("", df)]) ]
 ;
@@ -446,26 +447,6 @@ value rec same_type_expr ct ce =
   | _ → False ]
 ;
 
-value rec common_id loc t e =
-  match (t, e) with
-  [ (<:ctyp< $lid:s1$ >>, <:expr< $lid:s2$ >>) when s1 = s2 → Lident s1
-  | (<:ctyp< $uid:s1$ >>, <:expr< $uid:s2$ >>) when s1 = s2 → Lident s1
-  | (<:ctyp< $t1$.$lid:s1$ >>, <:expr< $e1$.$lid:s2$ >>) when s1 = s2 →
-      Ldot (common_id loc t1 e1) s1
-  | (<:ctyp< $t1$.$uid:s1$ >>, <:expr< $e1$.$uid:s2$ >>) when s1 = s2 →
-      Ldot (common_id loc t1 e1) s1
-  | _ → error loc "this expression should repeat the class id inherited" ]
-;
-
-value rec type_id loc t =
-  match t with
-  [ <:ctyp< $lid:s1$ >> → Lident s1
-  | <:ctyp< $uid:s1$ >> → Lident s1
-  | <:ctyp< $t1$.$lid:s1$ >> → Ldot (type_id loc t1) s1
-  | <:ctyp< $t1$.$uid:s1$ >> → Ldot (type_id loc t1) s1
-  | _ → error loc "type identifier expected" ]
-;
-
 value rec module_expr_long_id =
   fun
   [ <:module_expr< $me1$ ( $me2$ ) >> →
@@ -768,7 +749,8 @@ value rec expr =
         match sep_expr_acc [] e with
         [ [(loc, ml, <:expr< $uid:s$ >>) :: l] →
             let ca = not Prtools.no_constructors_arity.val in
-            (mkexp loc (ocaml_pexp_construct (mkli s ml) None ca), l)
+            let cloc = mkloc loc in
+            (mkexp loc (ocaml_pexp_construct cloc (mkli s ml) None ca), l)
         | [(loc, ml, <:expr< $lid:s$ >>) :: l] →
             (mkexp loc (ocaml_pexp_ident (mkli s ml)), l)
         | [(_, [], e) :: l] → (expr e, l)
@@ -780,7 +762,9 @@ value rec expr =
              match e2 with
              [ <:expr< $lid:s$ >> →
                  let loc = Ploc.encl loc1 loc2 in
-                 (loc, mkexp loc (ocaml_pexp_field e1 (mkli (conv_lab s) ml)))
+                 let li = mkli (conv_lab s) ml in
+                 let e = ocaml_pexp_field (mkloc loc) e1 li in
+                 (loc, mkexp loc e)
              | _ → error (loc_of_expr e2) "lowercase identifier expected" ])
           (loc, e) l
       in
@@ -862,7 +846,7 @@ value rec expr =
                (mkexp loc (ocaml_pexp_ident (array_function "Array" "set")))
                [("", expr e1); ("", expr e2); ("", expr v)])
       | ExBae loc e el → expr (bigarray_set loc e (uv el) v)
-      | <:expr< $lid:lab$ >> → mkexp loc (ocaml_pexp_setinstvar lab (expr v))
+      | ExLid _ lab → mkexp loc (ocaml_pexp_setinstvar (uv lab) (expr v))
       | ExSte _ e1 e2 →
           mkexp loc
             (ocaml_pexp_apply
@@ -1026,7 +1010,9 @@ value rec expr =
             match uv eo with
             [ Some e → expr e
             | None →
-                mkexp loc (ocaml_pexp_construct (Lident "()") None False) ]
+                let cloc = mkloc sloc in
+                let e = ocaml_pexp_construct cloc (Lident "()") None False in
+                mkexp loc e ]
           in
           mkexp loc (pexp_reply (mkloc loc) e (mkloc sloc, uv s))
       | None → error loc "no 'reply' in this ocaml version" ]
@@ -1056,7 +1042,8 @@ value rec expr =
   | ExTyc loc e t → mkexp loc (Pexp_constraint (expr e) (Some (ctyp t)) None)
   | ExUid loc s →
       let ca = not Prtools.no_constructors_arity.val in
-      mkexp loc (ocaml_pexp_construct (Lident (conv_con (uv s))) None ca)
+      let cloc = mkloc loc in
+      mkexp loc (ocaml_pexp_construct cloc (Lident (conv_con (uv s))) None ca)
   | ExVrn loc s →
       match ocaml_pexp_variant with
       [ Some (_, pexp_variant) → mkexp loc (pexp_variant (uv s, None))
@@ -1561,5 +1548,8 @@ value directive loc =
 value phrase =
   fun
   [ StDir loc d dp → Ptop_dir (uv d) (directive loc (uv dp))
-  | si → Ptop_def (str_item si []) ]
+  | si → do {
+      glob_fname.val := Plexing.input_file.val;
+      Ptop_def (str_item si [])
+    } ]
 ;
