@@ -1,6 +1,6 @@
 (* camlp5r *)
-(* $Id: main.ml,v 6.8 2011-03-15 13:49:11 deraugla Exp $ *)
-(* Copyright (c) INRIA 2007-2011 *)
+(* $Id: main.ml,v 6.11 2013-03-13 06:48:13 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2012 *)
 
 #load "q_MLast.cmo";
 
@@ -17,6 +17,11 @@ value string_of_loc fname line bp ep =
 ;
 
 value print_location loc =
+  let loc =
+    if Ploc.file_name loc = "" then
+      Ploc.make_loc Pcaml.input_file.val 1 0 (0, 1) ""
+    else loc
+  in
   let fname = Ploc.file_name loc in
   let bp = Ploc.first_pos loc in
   let ep = Ploc.last_pos loc in
@@ -218,6 +223,10 @@ Pcaml.add_directive "option"
        match parse_options [s] with
        [ Some 0 | None -> ()
        | Some x -> failwith "bad option" ]
+   | Some <:expr< $str:s1$ $str:s2$ >> ->
+       match parse_options [s1; s2] with
+       [ Some 0 | None -> ()
+       | Some x -> failwith "bad option" ]
    | Some _ | None -> raise Not_found ])
 ;
 
