@@ -1,5 +1,5 @@
 (* camlp5r *)
-(* $Id: parserify.ml,v 6.3 2012-01-09 14:22:21 deraugla Exp $ *)
+(* $Id: parserify.ml,v 6.5 2013-03-14 21:34:32 deraugla Exp $ *)
 (* Copyright (c) INRIA 2007-2012 *)
 
 #load "q_MLast.cmo";
@@ -69,6 +69,20 @@ value err =
   | e -> SpoQues e ]
 ;
 
+value rec simpl =
+  fun
+  [ <:expr<
+      match try Some $f$ with [ Stream.Failure -> None ] with
+      [ Some $lid:s1$ -> $lid:s2$
+      | _ -> raise Stream.Failure ]
+    >> as e ->
+      if s1 = s2 then f else e
+  | <:expr< match $e$ with [ Some $p1$ → $e1$ | _ → $e2$ ] >> →
+      <:expr< match $e$ with [ Some $p1$ → $e1$ | _ → $simpl e2$ ] >>
+  | e →
+      e ]
+;
+
 value rec unstream_pattern_kont =
   fun
   [ <:expr<
@@ -94,6 +108,22 @@ value rec unstream_pattern_kont =
   | <:expr< let $p$ = strm__ in $e$ >> ->
       let (sp, epo, e) = unstream_pattern_kont e in
       ([(SpStr loc p, SpoNoth) :: sp], epo, e)
+  | <:expr<
+      match try Some ($f$ strm__) with [ Stream.Failure → None ] with
+      [ Some $lid:s1$ → $lid:s2$
+      | _ → raise Stream.Failure ]
+    >> as e →
+      if s1 = s2 then
+        ([(SpNtr loc <:patt< a >> f, SpoBang)], None, <:expr< a >>)
+      else
+        ([], None, e)
+  | <:expr<
+      match try Some $e1$ with [ Stream.Failure → None ] with
+      [ Some $lid:s$ → $e2$
+      | _ → raise Stream.Failure ]
+    >> →
+      let e = <:expr< let $lid:s$ = $e1$ in $e2$ >> in
+      unstream_pattern_kont e
   | <:expr< let $p$ = $e1$ in $e2$ >> as ge ->
       if contains_strm__ e1 then
         let (f, err) =
@@ -186,6 +216,19 @@ value rec unparser_cases_list =
       in
       let spel = unparser_cases_list e2 in
       [spe :: spel]
+  | <:expr<
+      match try Some $f$ with [ Stream.Failure -> None ] with
+      [ Some $p1$ -> $e1$
+      | _ -> $e2$ ]
+    >> ->
+      let e =
+        <:expr<
+          match try Some $simpl f$ with [ Stream.Failure -> None ] with
+          [ Some $p1$ -> $simpl e1$
+          | _ -> $simpl e2$ ]
+        >>
+      in
+      [([], None, e)]
   | <:expr< try $f$ strm__ with [ Stream.Failure -> $e$ ] >> ->
       let spe = ([(SpNtr loc <:patt< a >> f, SpoNoth)], None, <:expr< a >>) in
       let spel = unparser_cases_list e in
