@@ -1,5 +1,5 @@
 (* camlp5r *)
-(* $Id: pa_r.ml,v 6.44 2013-02-28 17:27:54 deraugla Exp $ *)
+(* $Id: pa_r.ml,v 6.48 2013-07-02 16:12:43 deraugla Exp $ *)
 (* Copyright (c) INRIA 2007-2012 *)
 
 #load "pa_extend.cmo";
@@ -13,9 +13,12 @@ Pcaml.no_constructors_arity.val := False;
 
 do {
   let odfa = Plexer.dollar_for_antiquotation.val in
+  let odni = Plexer.dot_newline_is.val in
   Plexer.dollar_for_antiquotation.val := False;
   Plexer.utf8_lexing.val := True;
+  Plexer.dot_newline_is.val := ";";
   Grammar.Unsafe.gram_reinit gram (Plexer.gmake ());
+  Plexer.dot_newline_is.val := odni;
   Plexer.dollar_for_antiquotation.val := odfa;
   Grammar.Unsafe.clear_entry interf;
   Grammar.Unsafe.clear_entry implem;
@@ -122,40 +125,6 @@ value rec generalized_type_of_type =
       ([], t) ]
 ;
 
-value start_with s s_ini =
-  let len = String.length s_ini in
-  String.length s >= len && String.sub s 0 len = s_ini
-;
-
-value greek_tab =
-  ["α"; "β"; "γ"; "δ"; "ε"; "ζ"; "η"; "θ"; "ι"; "κ"; "λ"; "μ"; "ν"; "ξ";
-   "ο"; "π"; "ρ"; "σ"; "τ"; "υ"; "φ"; "χ"; "ψ"; "ω"]
-;
-value index_tab = [""; "₁"; "₂"; "₃"; "₄"; "₅"; "₆"; "₇"; "₈"; "₉"];
-value ascii_of_greek s =
-  loop 0 greek_tab where rec loop i =
-    fun
-    [ [g :: gl] -> do {
-        if start_with s g then do {
-          let c1 = Char.chr (Char.code 'a' + i) in
-          let glen = String.length g in
-          let rest = String.sub s glen (String.length s - glen) in
-          loop 0 index_tab where rec loop i =
-            fun
-            [ [k :: kl] -> do {
-                if rest = k then do {
-                  let s2 = if i = 0 then "" else string_of_int i in
-                  String.make 1 c1 ^ s2
-                }
-                else loop (i + 1) kl
-              }
-            | [] -> s ]
-        }
-        else loop (i + 1) gl
-      }
-    | [] -> s ]
-;
-
 value warned = ref False;
 value warning_deprecated_since_6_00 loc =
   if not warned.val then do {
@@ -206,8 +175,8 @@ EXTEND
       | "include"; me = module_expr -> <:str_item< include $me$ >>
       | "module"; r = V (FLAG "rec"); l = V (LIST1 mod_binding SEP "and") ->
           <:str_item< module $_flag:r$ $_list:l$ >>
-      | "module"; "type"; i = V UIDENT "uid" ""; mt = mod_type_fun_binding ->
-          <:str_item< module type $_uid:i$ = $mt$ >>
+      | "module"; "type"; i = V ident ""; mt = mod_type_fun_binding ->
+          <:str_item< module type $_:i$ = $mt$ >>
       | "open"; i = V mod_ident "list" "" -> <:str_item< open $_:i$ >>
       | "type"; tdl = V (LIST1 type_decl SEP "and") ->
           <:str_item< type $_list:tdl$ >>
@@ -274,8 +243,8 @@ EXTEND
       | "module"; rf = V (FLAG "rec");
         l = V (LIST1 mod_decl_binding SEP "and") ->
           <:sig_item< module $_flag:rf$ $_list:l$ >>
-      | "module"; "type"; i = V UIDENT "uid" ""; "="; mt = module_type ->
-          <:sig_item< module type $_uid:i$ = $mt$ >>
+      | "module"; "type"; i = V ident ""; "="; mt = module_type ->
+          <:sig_item< module type $_:i$ = $mt$ >>
       | "open"; i = V mod_ident "list" "" -> <:sig_item< open $_:i$ >>
       | "type"; tdl = V (LIST1 type_decl SEP "and") ->
           <:sig_item< type $_list:tdl$ >>
@@ -320,6 +289,9 @@ EXTEND
       | "match"; e = SELF; "with"; "["; l = V (LIST0 match_case SEP "|");
         "]" ->
           <:expr< match $e$ with [ $_list:l$ ] >>
+      | "match"; e = SELF; "with"; "|"; l = V (LIST0 match_case SEP "|");
+        "end" ->
+          <:expr< match $e$ with [ $_list:l$ ] >>
       | "match"; e = SELF; "with"; p1 = ipatt; "->"; e1 = SELF ->
           <:expr< match $e$ with $p1$ -> $e1$ >>
       | "try"; e = SELF; "with"; "["; l = V (LIST0 match_case SEP "|"); "]" ->
@@ -572,7 +544,7 @@ EXTEND
   ;
   simple_type_parameter:
     [ [ "'"; i = ident -> Some i
-      | i = GIDENT -> Some (ascii_of_greek i)
+      | i = GIDENT -> Some (greek_ascii_equiv i)
       | "_" -> None ] ]
   ;
   ctyp:
@@ -596,7 +568,7 @@ EXTEND
       [ t1 = SELF; "."; t2 = SELF -> <:ctyp< $t1$ . $t2$ >> ]
     | "simple"
       [ "'"; i = V ident "" -> <:ctyp< '$_:i$ >>
-      | i = GIDENT -> <:ctyp< '$ascii_of_greek i$ >>
+      | i = GIDENT -> <:ctyp< '$greek_ascii_equiv i$ >>
       | "_" -> <:ctyp< _ >>
       | i = V LIDENT -> <:ctyp< $_lid:i$ >>
       | i = V UIDENT -> <:ctyp< $_uid:i$ >>
