@@ -1,5 +1,5 @@
 (* camlp5r *)
-(* $Id: q_MLast.ml,v 6.40 2013-02-28 17:27:54 deraugla Exp $ *)
+(* $Id: q_MLast.ml,v 6.43 2013-07-02 16:12:43 deraugla Exp $ *)
 (* Copyright (c) INRIA 2007-2012 *)
 
 #load "pa_extend.cmo";
@@ -263,39 +263,7 @@ value generalized_type_of_type t =
   (Qast.List tl, rt)
 ;
 
-value start_with s s_ini =
-  let len = String.length s_ini in
-  String.length s >= len && String.sub s 0 len = s_ini
-;
-
-value greek_tab =
-  ["α"; "β"; "γ"; "δ"; "ε"; "ζ"; "η"; "θ"; "ι"; "κ"; "λ"; "μ"; "ν"; "ξ";
-   "ο"; "π"; "ρ"; "σ"; "τ"; "υ"; "φ"; "χ"; "ψ"; "ω"]
-;
-value index_tab = [""; "₁"; "₂"; "₃"; "₄"; "₅"; "₆"; "₇"; "₈"; "₉"];
-value ascii_of_greek s =
-  loop 0 greek_tab where rec loop i =
-    fun
-    [ [g :: gl] -> do {
-        if start_with s g then do {
-          let c1 = Char.chr (Char.code 'a' + i) in
-          let glen = String.length g in
-          let rest = String.sub s glen (String.length s - glen) in
-          loop 0 index_tab where rec loop i =
-            fun
-            [ [k :: kl] -> do {
-                if rest = k then do {
-                  let s2 = if i = 0 then "" else string_of_int i in
-                  Qast.Str (String.make 1 c1 ^ s2)
-                }
-                else loop (i + 1) kl
-              }
-            | [] -> Qast.Str s ]
-        }
-        else loop (i + 1) gl
-      }
-    | [] -> Qast.Str s ]
-;
+value greek_ascii_equiv s = Qast.Str (Pcaml.greek_ascii_equiv s);
 
 value warned = ref False;
 value warning_deprecated_since_6_00 loc =
@@ -351,7 +319,7 @@ EXTEND
       | "include"; me = module_expr -> Qast.Node "StInc" [Qast.Loc; me]
       | "module"; r = SV (FLAG "rec"); l = SV (LIST1 mod_binding SEP "and") ->
           Qast.Node "StMod" [Qast.Loc; r; l]
-      | "module"; "type"; i = SV UIDENT; mt = mod_type_fun_binding ->
+      | "module"; "type"; i = SV ident ""; mt = mod_type_fun_binding ->
           Qast.Node "StMty" [Qast.Loc; i; mt]
       | "open"; i = SV mod_ident "list" "" -> Qast.Node "StOpn" [Qast.Loc; i]
       | "type"; tdl = SV (LIST1 type_decl SEP "and") ->
@@ -422,7 +390,7 @@ EXTEND
       | "module"; rf = SV (FLAG "rec");
         l = SV (LIST1 mod_decl_binding SEP "and") ->
           Qast.Node "SgMod" [Qast.Loc; rf; l]
-      | "module"; "type"; i = SV UIDENT; "="; mt = module_type ->
+      | "module"; "type"; i = SV ident ""; "="; mt = module_type ->
           Qast.Node "SgMty" [Qast.Loc; i; mt]
       | "open"; i = SV mod_ident "list" "" -> Qast.Node "SgOpn" [Qast.Loc; i]
       | "type"; tdl = SV (LIST1 type_decl SEP "and") ->
@@ -474,6 +442,9 @@ EXTEND
       | "match"; e = SELF; "with"; "["; l = SV (LIST0 match_case SEP "|");
         "]" ->
           Qast.Node "ExMat" [Qast.Loc; e; l]
+      | "match"; e = SELF; "with"; "|"; l = SV (LIST0 match_case SEP "|");
+        "end" ->
+          Qast.Node "ExMat" [Qast.Loc; e; l]
       | "match"; e = SELF; "with"; p1 = ipatt; "->"; e1 = SELF ->
           Qast.Node "ExMat"
             [Qast.Loc; e;
@@ -949,7 +920,7 @@ EXTEND
   ;
   simple_type_parameter:
     [ [ "'"; i = ident -> Qast.Option (Some i)
-      | i = GIDENT -> Qast.Option (Some (ascii_of_greek i))
+      | i = GIDENT -> Qast.Option (Some (greek_ascii_equiv i))
       | "_" -> Qast.Option None ] ]
   ;
   ctyp:
@@ -972,7 +943,7 @@ EXTEND
     | "simple"
       [ "'"; i = SV ident "" -> Qast.Node "TyQuo" [Qast.Loc; i]
       | i = GIDENT ->
-          Qast.Node "TyQuo" [Qast.Loc; Qast.VaVal (ascii_of_greek i)]
+          Qast.Node "TyQuo" [Qast.Loc; Qast.VaVal (greek_ascii_equiv i)]
       | "_" -> Qast.Node "TyAny" [Qast.Loc]
       | i = SV LIDENT -> Qast.Node "TyLid" [Qast.Loc; i]
       | i = SV UIDENT -> Qast.Node "TyUid" [Qast.Loc; i]
