@@ -1,6 +1,6 @@
 (***********************************************************************)
 (*                                                                     *)
-(*                                OCaml                                *)
+(*                           Objective Caml                            *)
 (*                                                                     *)
 (*            Xavier Leroy, projet Cristal, INRIA Rocquencourt         *)
 (*                                                                     *)
@@ -33,9 +33,6 @@ and core_type_desc =
   | Ptyp_alias of core_type * string
   | Ptyp_variant of row_field list * bool * label list option
   | Ptyp_poly of string list * core_type
-  | Ptyp_package of package_type
-
-and package_type = Longident.t * (Longident.t * core_type) list
 
 and core_field_type =
   { pfield_desc: core_field_desc;
@@ -49,7 +46,7 @@ and row_field =
     Rtag of label * bool * core_type list
   | Rinherit of core_type
 
-(* Type expressions for the class language *)
+(* XXX Type expressions for the class language *)
 
 type 'a class_infos =
   { pci_virt: virtual_flag;
@@ -73,13 +70,12 @@ and pattern_desc =
   | Ppat_tuple of pattern list
   | Ppat_construct of Longident.t * pattern option * bool
   | Ppat_variant of label * pattern option
-  | Ppat_record of (Longident.t * pattern) list * closed_flag
+  | Ppat_record of (Longident.t * pattern) list
   | Ppat_array of pattern list
   | Ppat_or of pattern * pattern
   | Ppat_constraint of pattern * core_type
   | Ppat_type of Longident.t
   | Ppat_lazy of pattern
-  | Ppat_unpack of string
 
 type expression =
   { pexp_desc: expression_desc;
@@ -116,9 +112,6 @@ and expression_desc =
   | Pexp_lazy of expression
   | Pexp_poly of expression * core_type option
   | Pexp_object of class_structure
-  | Pexp_newtype of string * expression
-  | Pexp_pack of module_expr
-  | Pexp_open of Longident.t * expression
 
 (* Value descriptions *)
 
@@ -129,7 +122,7 @@ and value_description =
 (* Type declarations *)
 
 and type_declaration =
-  { ptype_params: string option list;
+  { ptype_params: string list;
     ptype_cstrs: (core_type * core_type * Location.t) list;
     ptype_kind: type_kind;
     ptype_private: private_flag;
@@ -139,8 +132,7 @@ and type_declaration =
 
 and type_kind =
     Ptype_abstract
-  | Ptype_variant of
-      (string * core_type list * core_type option * Location.t) list
+  | Ptype_variant of (string * core_type list * Location.t) list
   | Ptype_record of
       (string * mutable_flag * core_type * Location.t) list
 
@@ -187,15 +179,14 @@ and class_expr_desc =
 and class_structure = pattern * class_field list
 
 and class_field =
-    Pcf_inher of override_flag * class_expr * string option
+    Pcf_inher of class_expr * string option
   | Pcf_valvirt of (string * mutable_flag * core_type * Location.t)
-  | Pcf_val of
-      (string * mutable_flag * override_flag * expression * Location.t)
-  | Pcf_virt of (string * private_flag * core_type * Location.t)
-  | Pcf_meth of
-      (string * private_flag * override_flag * expression * Location.t)
-  | Pcf_cstr of (core_type * core_type * Location.t)
-  | Pcf_init of expression
+  | Pcf_val   of (string * mutable_flag * expression * Location.t)
+  | Pcf_virt  of (string * private_flag * core_type * Location.t)
+  | Pcf_meth  of (string * private_flag * expression * Location.t)
+  | Pcf_cstr  of (core_type * core_type * Location.t)
+  | Pcf_let   of rec_flag * (pattern * expression) list * Location.t
+  | Pcf_init  of expression
 
 and class_declaration = class_expr class_infos
 
@@ -210,7 +201,6 @@ and module_type_desc =
   | Pmty_signature of signature
   | Pmty_functor of string * module_type * module_type
   | Pmty_with of module_type * (Longident.t * with_constraint) list
-  | Pmty_typeof of module_expr
 
 and signature = signature_item list
 
@@ -237,8 +227,6 @@ and modtype_declaration =
 and with_constraint =
     Pwith_type of type_declaration
   | Pwith_module of Longident.t
-  | Pwith_typesubst of type_declaration
-  | Pwith_modsubst of Longident.t
 
 (* Value expressions for the module language *)
 
@@ -252,7 +240,6 @@ and module_expr_desc =
   | Pmod_functor of string * module_type * module_expr
   | Pmod_apply of module_expr * module_expr
   | Pmod_constraint of module_expr * module_type
-  | Pmod_unpack of expression
 
 and structure = structure_item list
 
