@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: camlp5_comm.sh,v 6.2 2012-03-01 03:33:19 deraugla Exp $
+# $Id: camlp5_comm.sh,v 6.5 2012-03-03 01:38:08 deraugla Exp $
 
 ARGS1="-mode $MODE"
 FILE=
@@ -21,11 +21,11 @@ if test "$2" = "camlp5r" -o "$2" = "camlp5"; then
   else WHAT="${CAMLP5N}"; fi
   case "$COMPWITH/$WHAT" in
   old/*)
-    COMM="ocamlrun$EXE ../boot/$WHAT$EXE -nolib -I ../boot";;
+    COMM="${OCAMLN}run$EXE ../boot/$WHAT$EXE -nolib -I ../boot";;
   new/${CAMLP5N})
-    COMM="ocamlrun$EXE ../main/$WHAT$EXE -nolib -I ../meta -I ../etc";;
+    COMM="${OCAMLN}run$EXE ../main/$WHAT$EXE -nolib -I ../meta -I ../etc";;
   new/${CAMLP5N}r)
-    COMM="ocamlrun$EXE ../meta/$WHAT$EXE -nolib -I ../meta -I ../etc";;
+    COMM="${OCAMLN}run$EXE ../meta/$WHAT$EXE -nolib -I ../meta -I ../etc";;
   *)
     echo "internal error: bad value of COMPWITH/WHAT" 1>&2; exit 2;;
   esac
